@@ -15,12 +15,17 @@ func (p Base64URLEncode) Alias() []string {
 	return []string{"b64url-enc", "b64url-encode"}
 }
 
-func (p Base64URLEncode) Transform(data []byte, _ ...Flag) (string, error) {
+func (p Base64URLEncode) Transform(data []byte, f ...Flag) (string, error) {
+	raw := checkBase64RawFlag(f)
+
+	if raw {
+		return base64.RawURLEncoding.EncodeToString(data), nil
+	}
 	return base64.URLEncoding.EncodeToString(data), nil
 }
 
 func (p Base64URLEncode) Flags() []Flag {
-	return nil
+	return []Flag{base64RawFlag}
 }
 
 func (p Base64URLEncode) Title() string {
@@ -46,13 +51,20 @@ func (p Base64URLDecode) Alias() []string {
 	return []string{"b64url-dec", "b64url-decode"}
 }
 
-func (p Base64URLDecode) Transform(data []byte, _ ...Flag) (string, error) {
-	decodedString, err := base64.URLEncoding.DecodeString(string(data))
+func (p Base64URLDecode) Transform(data []byte, f ...Flag) (string, error) {
+	raw := checkBase64RawFlag(f)
+	var decodedString []byte
+	var err error
+	if raw {
+		decodedString, err = base64.RawURLEncoding.DecodeString(string(data))
+	} else {
+		decodedString, err = base64.URLEncoding.DecodeString(string(data))
+	}
 	return string(decodedString), err
 }
 
 func (p Base64URLDecode) Flags() []Flag {
-	return nil
+	return []Flag{base64RawFlag}
 }
 
 func (p Base64URLDecode) Title() string {
