@@ -2,12 +2,9 @@ package processors
 
 import (
 	"fmt"
-	"github.com/mcnijman/go-emailaddress"
-	"regexp"
-	"sort"
-	"strings"
-
 	"github.com/abhimanyu003/sttr/utils"
+	"regexp"
+	"strings"
 
 	"github.com/iancoleman/strcase"
 )
@@ -302,76 +299,6 @@ func (p CountWords) FilterValue() string {
 	return p.Title()
 }
 
-// CountLines count number of words in string.
-// Example: "line 1\n line 2" = 2
-type CountLines struct{}
-
-func (p CountLines) Name() string {
-	return "count-lines"
-}
-
-func (p CountLines) Alias() []string {
-	return nil
-}
-
-func (p CountLines) Transform(data []byte, _ ...Flag) (string, error) {
-	var lines int
-	if len(data) > 0 {
-		lines = strings.Count(string(data), "\n") + 1
-	}
-	return fmt.Sprintf("%d", lines), nil
-}
-
-func (p CountLines) Flags() []Flag {
-	return nil
-}
-
-func (p CountLines) Title() string {
-	return "Count Number of Lines"
-}
-
-func (p CountLines) Description() string {
-	return "Count the number of lines in your text"
-}
-
-func (p CountLines) FilterValue() string {
-	return p.Title()
-}
-
-// SortLines sort given lines, it's not a natural sort.
-// Example: 2\n 1\n -> 1\n 2\n
-type SortLines struct{}
-
-func (p SortLines) Name() string {
-	return "sort-lines"
-}
-
-func (p SortLines) Alias() []string {
-	return nil
-}
-
-func (p SortLines) Transform(data []byte, _ ...Flag) (string, error) {
-	sorted := strings.Split(string(data), "\n")
-	sort.Strings(sorted)
-	return strings.Join(sorted, "\n"), nil
-}
-
-func (p SortLines) Flags() []Flag {
-	return nil
-}
-
-func (p SortLines) Title() string {
-	return "SortLines"
-}
-
-func (p SortLines) Description() string {
-	return "Sort lines alphabetically"
-}
-
-func (p SortLines) FilterValue() string {
-	return p.Title()
-}
-
 // Reverse reverse a given string
 // Example: "test" to "tset"
 type Reverse struct{}
@@ -407,57 +334,3 @@ func (p Reverse) Description() string {
 func (p Reverse) FilterValue() string {
 	return p.Title()
 }
-
-// ExtractEmails will pluck all the valid emails from a given text.
-type ExtractEmails struct{}
-
-func (p ExtractEmails) Name() string {
-	return "extract-emails"
-}
-
-func (p ExtractEmails) Alias() []string {
-	return []string{"find-emails", "find-email", "extract-email"}
-}
-
-func (p ExtractEmails) Transform(data []byte, f ...Flag) (string, error) {
-	var emails []string
-	extracted := emailaddress.FindWithIcannSuffix(data, false)
-	for _, e := range extracted {
-		emails = append(emails, e.String())
-	}
-
-	separator := "\n"
-	for _, flag := range f {
-		if flag.Short == "s" {
-			x, ok := flag.Value.(string)
-			if ok {
-				separator = x
-			}
-		}
-	}
-	return strings.Join(emails, separator), nil
-}
-
-func (p ExtractEmails) Flags() []Flag {
-	return []Flag{
-		{
-			Name:  "separator",
-			Short: "s",
-			Desc:  "Separator to split multiple emails",
-			Value: "",
-			Type:  FlagString,
-		},
-	}
-}
-
-func (p ExtractEmails) Title() string {
-	return "Extract Emails"
-}
-
-func (p ExtractEmails) Description() string {
-	return "Extract emails from given text"
-}
-
-func (p ExtractEmails) FilterValue() string {
-	return p.Title()
-}
